# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.model_artifact import ModelArtifact  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestModelArtifact(unittest.TestCase):
    """ModelArtifact unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ModelArtifact
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.model_artifact.ModelArtifact()  # noqa: E501
        if include_optional :
            return ModelArtifact(
                id = 56, 
                created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                version = '', 
                labels = '', 
                artifacts = '', 
                artifact_types = [
                    'TFLITE'
                    ], 
                metadata = {
                    'key' : null
                    }, 
                url = ''
            )
        else :
            return ModelArtifact(
                id = 56,
                created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                version = '',
                labels = '',
                artifacts = '',
                artifact_types = [
                    'TFLITE'
                    ],
                metadata = {
                    'key' : null
                    },
                url = '',
        )

    def testModelArtifact(self):
        """Test ModelArtifact"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class GcodeFile(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'user': 'int',
        'name': 'str',
        'file': 'str',
        'file_hash': 'str',
        'octoprint_device': 'str',
        'url': 'str'
    }

    attribute_map = {
        'id': 'id',
        'user': 'user',
        'name': 'name',
        'file': 'file',
        'file_hash': 'file_hash',
        'octoprint_device': 'octoprint_device',
        'url': 'url'
    }

    def __init__(self, id=None, user=None, name=None, file=None, file_hash=None, octoprint_device=None, url=None, local_vars_configuration=None):  # noqa: E501
        """GcodeFile - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user = None
        self._name = None
        self._file = None
        self._file_hash = None
        self._octoprint_device = None
        self._url = None
        self.discriminator = None

        self.id = id
        self.user = user
        self.name = name
        self.file = file
        self.file_hash = file_hash
        self.octoprint_device = octoprint_device
        self.url = url

    @property
    def id(self):
        """Gets the id of this GcodeFile.  # noqa: E501


        :return: The id of this GcodeFile.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this GcodeFile.


        :param id: The id of this GcodeFile.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def user(self):
        """Gets the user of this GcodeFile.  # noqa: E501


        :return: The user of this GcodeFile.  # noqa: E501
        :rtype: int
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this GcodeFile.


        :param user: The user of this GcodeFile.  # noqa: E501
        :type user: int
        """
        if self.local_vars_configuration.client_side_validation and user is None:  # noqa: E501
            raise ValueError("Invalid value for `user`, must not be `None`")  # noqa: E501

        self._user = user

    @property
    def name(self):
        """Gets the name of this GcodeFile.  # noqa: E501


        :return: The name of this GcodeFile.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GcodeFile.


        :param name: The name of this GcodeFile.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 255):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `255`")  # noqa: E501

        self._name = name

    @property
    def file(self):
        """Gets the file of this GcodeFile.  # noqa: E501


        :return: The file of this GcodeFile.  # noqa: E501
        :rtype: str
        """
        return self._file

    @file.setter
    def file(self, file):
        """Sets the file of this GcodeFile.


        :param file: The file of this GcodeFile.  # noqa: E501
        :type file: str
        """
        if self.local_vars_configuration.client_side_validation and file is None:  # noqa: E501
            raise ValueError("Invalid value for `file`, must not be `None`")  # noqa: E501

        self._file = file

    @property
    def file_hash(self):
        """Gets the file_hash of this GcodeFile.  # noqa: E501


        :return: The file_hash of this GcodeFile.  # noqa: E501
        :rtype: str
        """
        return self._file_hash

    @file_hash.setter
    def file_hash(self, file_hash):
        """Sets the file_hash of this GcodeFile.


        :param file_hash: The file_hash of this GcodeFile.  # noqa: E501
        :type file_hash: str
        """
        if self.local_vars_configuration.client_side_validation and file_hash is None:  # noqa: E501
            raise ValueError("Invalid value for `file_hash`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                file_hash is not None and len(file_hash) > 255):
            raise ValueError("Invalid value for `file_hash`, length must be less than or equal to `255`")  # noqa: E501

        self._file_hash = file_hash

    @property
    def octoprint_device(self):
        """Gets the octoprint_device of this GcodeFile.  # noqa: E501


        :return: The octoprint_device of this GcodeFile.  # noqa: E501
        :rtype: str
        """
        return self._octoprint_device

    @octoprint_device.setter
    def octoprint_device(self, octoprint_device):
        """Sets the octoprint_device of this GcodeFile.


        :param octoprint_device: The octoprint_device of this GcodeFile.  # noqa: E501
        :type octoprint_device: str
        """
        if self.local_vars_configuration.client_side_validation and octoprint_device is None:  # noqa: E501
            raise ValueError("Invalid value for `octoprint_device`, must not be `None`")  # noqa: E501

        self._octoprint_device = octoprint_device

    @property
    def url(self):
        """Gets the url of this GcodeFile.  # noqa: E501


        :return: The url of this GcodeFile.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this GcodeFile.


        :param url: The url of this GcodeFile.  # noqa: E501
        :type url: str
        """
        if self.local_vars_configuration.client_side_validation and url is None:  # noqa: E501
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GcodeFile):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GcodeFile):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.cloudiot_device import CloudiotDevice  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestCloudiotDevice(unittest.TestCase):
    """CloudiotDevice unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CloudiotDevice
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.cloudiot_device.CloudiotDevice()  # noqa: E501
        if include_optional :
            return CloudiotDevice(
                num_id = -9223372036854775808, 
                task_topic = '', 
                config_topic = '', 
                state_topic = '', 
                gcp_project_id = '', 
                gcp_region = '', 
                gcp_cloudiot_device_registry = '', 
                mqtt_bridge_hostname = '', 
                mqtt_bridge_port = 56, 
                mqtt_client_id = '', 
                name = '', 
                id = '', 
                device = 56
            )
        else :
            return CloudiotDevice(
                num_id = -9223372036854775808,
                task_topic = '',
                config_topic = '',
                state_topic = '',
                gcp_project_id = '',
                gcp_region = '',
                gcp_cloudiot_device_registry = '',
                mqtt_bridge_hostname = '',
                mqtt_bridge_port = 56,
                mqtt_client_id = '',
                name = '',
                id = '',
                device = 56,
        )

    def testCloudiotDevice(self):
        """Test CloudiotDevice"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class Partner3DGeeksAlert(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'event': 'str',
        'token': 'str',
        'printer': 'str',
        '_print': 'str',
        'current_time': 'int',
        'time_left': 'int',
        'percent': 'int',
        'image': 'str',
        'action': 'str'
    }

    attribute_map = {
        'event': 'event',
        'token': 'token',
        'printer': 'printer',
        '_print': 'print',
        'current_time': 'currentTime',
        'time_left': 'timeLeft',
        'percent': 'percent',
        'image': 'image',
        'action': 'action'
    }

    def __init__(self, event=None, token=None, printer=None, _print=None, current_time=None, time_left=None, percent=None, image=None, action=None, local_vars_configuration=None):  # noqa: E501
        """Partner3DGeeksAlert - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._event = None
        self._token = None
        self._printer = None
        self.__print = None
        self._current_time = None
        self._time_left = None
        self._percent = None
        self._image = None
        self._action = None
        self.discriminator = None

        self.event = event
        self.token = token
        self.printer = printer
        self._print = _print
        self.current_time = current_time
        self.time_left = time_left
        self.percent = percent
        self.image = image
        self.action = action

    @property
    def event(self):
        """Gets the event of this Partner3DGeeksAlert.  # noqa: E501


        :return: The event of this Partner3DGeeksAlert.  # noqa: E501
        :rtype: str
        """
        return self._event

    @event.setter
    def event(self, event):
        """Sets the event of this Partner3DGeeksAlert.


        :param event: The event of this Partner3DGeeksAlert.  # noqa: E501
        :type event: str
        """
        if self.local_vars_configuration.client_side_validation and event is None:  # noqa: E501
            raise ValueError("Invalid value for `event`, must not be `None`")  # noqa: E501

        self._event = event

    @property
    def token(self):
        """Gets the token of this Partner3DGeeksAlert.  # noqa: E501


        :return: The token of this Partner3DGeeksAlert.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this Partner3DGeeksAlert.


        :param token: The token of this Partner3DGeeksAlert.  # noqa: E501
        :type token: str
        """
        if self.local_vars_configuration.client_side_validation and token is None:  # noqa: E501
            raise ValueError("Invalid value for `token`, must not be `None`")  # noqa: E501

        self._token = token

    @property
    def printer(self):
        """Gets the printer of this Partner3DGeeksAlert.  # noqa: E501


        :return: The printer of this Partner3DGeeksAlert.  # noqa: E501
        :rtype: str
        """
        return self._printer

    @printer.setter
    def printer(self, printer):
        """Sets the printer of this Partner3DGeeksAlert.


        :param printer: The printer of this Partner3DGeeksAlert.  # noqa: E501
        :type printer: str
        """
        if self.local_vars_configuration.client_side_validation and printer is None:  # noqa: E501
            raise ValueError("Invalid value for `printer`, must not be `None`")  # noqa: E501

        self._printer = printer

    @property
    def _print(self):
        """Gets the _print of this Partner3DGeeksAlert.  # noqa: E501


        :return: The _print of this Partner3DGeeksAlert.  # noqa: E501
        :rtype: str
        """
        return self.__print

    @_print.setter
    def _print(self, _print):
        """Sets the _print of this Partner3DGeeksAlert.


        :param _print: The _print of this Partner3DGeeksAlert.  # noqa: E501
        :type _print: str
        """
        if self.local_vars_configuration.client_side_validation and _print is None:  # noqa: E501
            raise ValueError("Invalid value for `_print`, must not be `None`")  # noqa: E501

        self.__print = _print

    @property
    def current_time(self):
        """Gets the current_time of this Partner3DGeeksAlert.  # noqa: E501


        :return: The current_time of this Partner3DGeeksAlert.  # noqa: E501
        :rtype: int
        """
        return self._current_time

    @current_time.setter
    def current_time(self, current_time):
        """Sets the current_time of this Partner3DGeeksAlert.


        :param current_time: The current_time of this Partner3DGeeksAlert.  # noqa: E501
        :type current_time: int
        """
        if self.local_vars_configuration.client_side_validation and current_time is None:  # noqa: E501
            raise ValueError("Invalid value for `current_time`, must not be `None`")  # noqa: E501

        self._current_time = current_time

    @property
    def time_left(self):
        """Gets the time_left of this Partner3DGeeksAlert.  # noqa: E501


        :return: The time_left of this Partner3DGeeksAlert.  # noqa: E501
        :rtype: int
        """
        return self._time_left

    @time_left.setter
    def time_left(self, time_left):
        """Sets the time_left of this Partner3DGeeksAlert.


        :param time_left: The time_left of this Partner3DGeeksAlert.  # noqa: E501
        :type time_left: int
        """
        if self.local_vars_configuration.client_side_validation and time_left is None:  # noqa: E501
            raise ValueError("Invalid value for `time_left`, must not be `None`")  # noqa: E501

        self._time_left = time_left

    @property
    def percent(self):
        """Gets the percent of this Partner3DGeeksAlert.  # noqa: E501


        :return: The percent of this Partner3DGeeksAlert.  # noqa: E501
        :rtype: int
        """
        return self._percent

    @percent.setter
    def percent(self, percent):
        """Sets the percent of this Partner3DGeeksAlert.


        :param percent: The percent of this Partner3DGeeksAlert.  # noqa: E501
        :type percent: int
        """
        if self.local_vars_configuration.client_side_validation and percent is None:  # noqa: E501
            raise ValueError("Invalid value for `percent`, must not be `None`")  # noqa: E501

        self._percent = percent

    @property
    def image(self):
        """Gets the image of this Partner3DGeeksAlert.  # noqa: E501


        :return: The image of this Partner3DGeeksAlert.  # noqa: E501
        :rtype: str
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this Partner3DGeeksAlert.


        :param image: The image of this Partner3DGeeksAlert.  # noqa: E501
        :type image: str
        """

        self._image = image

    @property
    def action(self):
        """Gets the action of this Partner3DGeeksAlert.  # noqa: E501


        :return: The action of this Partner3DGeeksAlert.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this Partner3DGeeksAlert.


        :param action: The action of this Partner3DGeeksAlert.  # noqa: E501
        :type action: str
        """
        if self.local_vars_configuration.client_side_validation and action is None:  # noqa: E501
            raise ValueError("Invalid value for `action`, must not be `None`")  # noqa: E501

        self._action = action

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Partner3DGeeksAlert):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Partner3DGeeksAlert):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from printnanny_api_client.api_client import ApiClient
from printnanny_api_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class MlOpsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def device_calibration_update_or_create(self, device_calibration_request, **kwargs):  # noqa: E501
        """device_calibration_update_or_create  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.device_calibration_update_or_create(device_calibration_request, async_req=True)
        >>> result = thread.get()

        :param device_calibration_request: (required)
        :type device_calibration_request: DeviceCalibrationRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DeviceCalibration
        """
        kwargs['_return_http_data_only'] = True
        return self.device_calibration_update_or_create_with_http_info(device_calibration_request, **kwargs)  # noqa: E501

    def device_calibration_update_or_create_with_http_info(self, device_calibration_request, **kwargs):  # noqa: E501
        """device_calibration_update_or_create  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.device_calibration_update_or_create_with_http_info(device_calibration_request, async_req=True)
        >>> result = thread.get()

        :param device_calibration_request: (required)
        :type device_calibration_request: DeviceCalibrationRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(DeviceCalibration, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'device_calibration_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method device_calibration_update_or_create" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'device_calibration_request' is set
        if self.api_client.client_side_validation and ('device_calibration_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['device_calibration_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `device_calibration_request` when calling `device_calibration_update_or_create`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'device_calibration_request' in local_var_params:
            body_params = local_var_params['device_calibration_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cookieAuth', 'tokenAuth']  # noqa: E501

        response_types_map = {
            400: "DeviceCalibration",
            200: "DeviceCalibration",
            201: "DeviceCalibration",
        }

        return self.api_client.call_api(
            '/api/device-calibrations/update-or-create/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def device_calibrations_list(self, **kwargs):  # noqa: E501
        """device_calibrations_list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.device_calibrations_list(async_req=True)
        >>> result = thread.get()

        :param page: A page number within the paginated result set.
        :type page: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PaginatedDeviceCalibrationList
        """
        kwargs['_return_http_data_only'] = True
        return self.device_calibrations_list_with_http_info(**kwargs)  # noqa: E501

    def device_calibrations_list_with_http_info(self, **kwargs):  # noqa: E501
        """device_calibrations_list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.device_calibrations_list_with_http_info(async_req=True)
        >>> result = thread.get()

        :param page: A page number within the paginated result set.
        :type page: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PaginatedDeviceCalibrationList, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'page'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method device_calibrations_list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cookieAuth', 'tokenAuth']  # noqa: E501

        response_types_map = {
            400: "DeviceCalibration",
            200: "PaginatedDeviceCalibrationList",
            201: "PaginatedDeviceCalibrationList",
        }

        return self.api_client.call_api(
            '/api/device-calibrations/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def device_calibrations_partial_update(self, id, **kwargs):  # noqa: E501
        """device_calibrations_partial_update  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.device_calibrations_partial_update(id, async_req=True)
        >>> result = thread.get()

        :param id: A unique integer value identifying this device calibration. (required)
        :type id: int
        :param patched_device_calibration_request:
        :type patched_device_calibration_request: PatchedDeviceCalibrationRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DeviceCalibration
        """
        kwargs['_return_http_data_only'] = True
        return self.device_calibrations_partial_update_with_http_info(id, **kwargs)  # noqa: E501

    def device_calibrations_partial_update_with_http_info(self, id, **kwargs):  # noqa: E501
        """device_calibrations_partial_update  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.device_calibrations_partial_update_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: A unique integer value identifying this device calibration. (required)
        :type id: int
        :param patched_device_calibration_request:
        :type patched_device_calibration_request: PatchedDeviceCalibrationRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(DeviceCalibration, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'id',
            'patched_device_calibration_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method device_calibrations_partial_update" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `device_calibrations_partial_update`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'patched_device_calibration_request' in local_var_params:
            body_params = local_var_params['patched_device_calibration_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cookieAuth', 'tokenAuth']  # noqa: E501

        response_types_map = {
            400: "DeviceCalibration",
            200: "DeviceCalibration",
            201: "DeviceCalibration",
        }

        return self.api_client.call_api(
            '/api/device-calibrations/{id}/', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def device_calibrations_retrieve(self, id, **kwargs):  # noqa: E501
        """device_calibrations_retrieve  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.device_calibrations_retrieve(id, async_req=True)
        >>> result = thread.get()

        :param id: A unique integer value identifying this device calibration. (required)
        :type id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DeviceCalibration
        """
        kwargs['_return_http_data_only'] = True
        return self.device_calibrations_retrieve_with_http_info(id, **kwargs)  # noqa: E501

    def device_calibrations_retrieve_with_http_info(self, id, **kwargs):  # noqa: E501
        """device_calibrations_retrieve  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.device_calibrations_retrieve_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: A unique integer value identifying this device calibration. (required)
        :type id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(DeviceCalibration, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method device_calibrations_retrieve" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `device_calibrations_retrieve`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cookieAuth', 'tokenAuth']  # noqa: E501

        response_types_map = {
            400: "DeviceCalibration",
            200: "DeviceCalibration",
            201: "DeviceCalibration",
        }

        return self.api_client.call_api(
            '/api/device-calibrations/{id}/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def device_calibrations_update(self, id, device_calibration_request, **kwargs):  # noqa: E501
        """device_calibrations_update  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.device_calibrations_update(id, device_calibration_request, async_req=True)
        >>> result = thread.get()

        :param id: A unique integer value identifying this device calibration. (required)
        :type id: int
        :param device_calibration_request: (required)
        :type device_calibration_request: DeviceCalibrationRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DeviceCalibration
        """
        kwargs['_return_http_data_only'] = True
        return self.device_calibrations_update_with_http_info(id, device_calibration_request, **kwargs)  # noqa: E501

    def device_calibrations_update_with_http_info(self, id, device_calibration_request, **kwargs):  # noqa: E501
        """device_calibrations_update  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.device_calibrations_update_with_http_info(id, device_calibration_request, async_req=True)
        >>> result = thread.get()

        :param id: A unique integer value identifying this device calibration. (required)
        :type id: int
        :param device_calibration_request: (required)
        :type device_calibration_request: DeviceCalibrationRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(DeviceCalibration, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'id',
            'device_calibration_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method device_calibrations_update" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `device_calibrations_update`")  # noqa: E501
        # verify the required parameter 'device_calibration_request' is set
        if self.api_client.client_side_validation and ('device_calibration_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['device_calibration_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `device_calibration_request` when calling `device_calibrations_update`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'device_calibration_request' in local_var_params:
            body_params = local_var_params['device_calibration_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cookieAuth', 'tokenAuth']  # noqa: E501

        response_types_map = {
            400: "DeviceCalibration",
            200: "DeviceCalibration",
            201: "DeviceCalibration",
        }

        return self.api_client.call_api(
            '/api/device-calibrations/{id}/', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def experiment_device_configs_list(self, **kwargs):  # noqa: E501
        """experiment_device_configs_list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.experiment_device_configs_list(async_req=True)
        >>> result = thread.get()

        :param page: A page number within the paginated result set.
        :type page: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PaginatedExperimentDeviceConfigList
        """
        kwargs['_return_http_data_only'] = True
        return self.experiment_device_configs_list_with_http_info(**kwargs)  # noqa: E501

    def experiment_device_configs_list_with_http_info(self, **kwargs):  # noqa: E501
        """experiment_device_configs_list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.experiment_device_configs_list_with_http_info(async_req=True)
        >>> result = thread.get()

        :param page: A page number within the paginated result set.
        :type page: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PaginatedExperimentDeviceConfigList, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'page'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method experiment_device_configs_list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cookieAuth', 'tokenAuth']  # noqa: E501

        response_types_map = {
            200: "PaginatedExperimentDeviceConfigList",
        }

        return self.api_client.call_api(
            '/api/experiment-device-configs/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def experiment_device_configs_retrieve(self, id, **kwargs):  # noqa: E501
        """experiment_device_configs_retrieve  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.experiment_device_configs_retrieve(id, async_req=True)
        >>> result = thread.get()

        :param id: A unique integer value identifying this experiment device config. (required)
        :type id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ExperimentDeviceConfig
        """
        kwargs['_return_http_data_only'] = True
        return self.experiment_device_configs_retrieve_with_http_info(id, **kwargs)  # noqa: E501

    def experiment_device_configs_retrieve_with_http_info(self, id, **kwargs):  # noqa: E501
        """experiment_device_configs_retrieve  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.experiment_device_configs_retrieve_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: A unique integer value identifying this experiment device config. (required)
        :type id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ExperimentDeviceConfig, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method experiment_device_configs_retrieve" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `experiment_device_configs_retrieve`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cookieAuth', 'tokenAuth']  # noqa: E501

        response_types_map = {
            200: "ExperimentDeviceConfig",
        }

        return self.api_client.call_api(
            '/api/experiment-device-configs/{id}/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def experiments_list(self, **kwargs):  # noqa: E501
        """experiments_list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.experiments_list(async_req=True)
        >>> result = thread.get()

        :param page: A page number within the paginated result set.
        :type page: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PaginatedExperimentList
        """
        kwargs['_return_http_data_only'] = True
        return self.experiments_list_with_http_info(**kwargs)  # noqa: E501

    def experiments_list_with_http_info(self, **kwargs):  # noqa: E501
        """experiments_list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.experiments_list_with_http_info(async_req=True)
        >>> result = thread.get()

        :param page: A page number within the paginated result set.
        :type page: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PaginatedExperimentList, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'page'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method experiments_list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cookieAuth', 'tokenAuth']  # noqa: E501

        response_types_map = {
            200: "PaginatedExperimentList",
        }

        return self.api_client.call_api(
            '/api/experiments/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def experiments_retrieve(self, id, **kwargs):  # noqa: E501
        """experiments_retrieve  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.experiments_retrieve(id, async_req=True)
        >>> result = thread.get()

        :param id: A unique integer value identifying this experiment. (required)
        :type id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Experiment
        """
        kwargs['_return_http_data_only'] = True
        return self.experiments_retrieve_with_http_info(id, **kwargs)  # noqa: E501

    def experiments_retrieve_with_http_info(self, id, **kwargs):  # noqa: E501
        """experiments_retrieve  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.experiments_retrieve_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: A unique integer value identifying this experiment. (required)
        :type id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Experiment, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method experiments_retrieve" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `experiments_retrieve`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cookieAuth', 'tokenAuth']  # noqa: E501

        response_types_map = {
            200: "Experiment",
        }

        return self.api_client.call_api(
            '/api/experiments/{id}/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def model_artifacts_list(self, **kwargs):  # noqa: E501
        """model_artifacts_list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.model_artifacts_list(async_req=True)
        >>> result = thread.get()

        :param page: A page number within the paginated result set.
        :type page: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PaginatedModelArtifactList
        """
        kwargs['_return_http_data_only'] = True
        return self.model_artifacts_list_with_http_info(**kwargs)  # noqa: E501

    def model_artifacts_list_with_http_info(self, **kwargs):  # noqa: E501
        """model_artifacts_list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.model_artifacts_list_with_http_info(async_req=True)
        >>> result = thread.get()

        :param page: A page number within the paginated result set.
        :type page: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PaginatedModelArtifactList, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'page'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method model_artifacts_list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cookieAuth', 'tokenAuth']  # noqa: E501

        response_types_map = {
            200: "PaginatedModelArtifactList",
        }

        return self.api_client.call_api(
            '/api/model-artifacts/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def model_artifacts_retrieve(self, id, **kwargs):  # noqa: E501
        """model_artifacts_retrieve  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.model_artifacts_retrieve(id, async_req=True)
        >>> result = thread.get()

        :param id: A unique integer value identifying this model artifact. (required)
        :type id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ModelArtifact
        """
        kwargs['_return_http_data_only'] = True
        return self.model_artifacts_retrieve_with_http_info(id, **kwargs)  # noqa: E501

    def model_artifacts_retrieve_with_http_info(self, id, **kwargs):  # noqa: E501
        """model_artifacts_retrieve  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.model_artifacts_retrieve_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: A unique integer value identifying this model artifact. (required)
        :type id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ModelArtifact, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method model_artifacts_retrieve" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `model_artifacts_retrieve`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cookieAuth', 'tokenAuth']  # noqa: E501

        response_types_map = {
            200: "ModelArtifact",
        }

        return self.api_client.call_api(
            '/api/model-artifacts/{id}/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.paginated_print_session_list import PaginatedPrintSessionList  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestPaginatedPrintSessionList(unittest.TestCase):
    """PaginatedPrintSessionList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PaginatedPrintSessionList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.paginated_print_session_list.PaginatedPrintSessionList()  # noqa: E501
        if include_optional :
            return PaginatedPrintSessionList(
                count = 123, 
                next = 'http://api.example.org/accounts/?page=4', 
                previous = 'http://api.example.org/accounts/?page=2', 
                results = [
                    printnanny_api_client.models.print_session.PrintSession(
                        id = 56, 
                        created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        octoprint_device = 56, 
                        active = True, 
                        session = '', 
                        filepos = -2147483648, 
                        print_progress = -2147483648, 
                        time_elapsed = -2147483648, 
                        time_remaining = -2147483648, 
                        user = 56, 
                        printer_profile = 56, 
                        gcode_file = 56, 
                        gcode_filename = '', 
                        octoprint_job = {
                            'key' : null
                            }, 
                        print_job_status = null, 
                        url = '', 
                        datesegment = '', )
                    ]
            )
        else :
            return PaginatedPrintSessionList(
        )

    def testPaginatedPrintSessionList(self):
        """Test PaginatedPrintSessionList"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class PrinterProfile(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'user': 'int',
        'octoprint_device': 'int',
        'axes_e_inverted': 'bool',
        'axes_e_speed': 'int',
        'axes_x_speed': 'int',
        'axes_x_inverted': 'bool',
        'axes_y_inverted': 'bool',
        'axes_y_speed': 'int',
        'axes_z_inverted': 'bool',
        'axes_z_speed': 'int',
        'extruder_count': 'int',
        'extruder_nozzle_diameter': 'float',
        'extruder_shared_nozzle': 'bool',
        'heated_bed': 'bool',
        'heated_chamber': 'bool',
        'model': 'str',
        'name': 'str',
        'octoprint_key': 'str',
        'volume_custom_box': 'dict(str, object)',
        'volume_depth': 'float',
        'volume_formfactor': 'str',
        'volume_height': 'float',
        'volume_origin': 'str',
        'volume_width': 'float',
        'url': 'str'
    }

    attribute_map = {
        'id': 'id',
        'user': 'user',
        'octoprint_device': 'octoprint_device',
        'axes_e_inverted': 'axes_e_inverted',
        'axes_e_speed': 'axes_e_speed',
        'axes_x_speed': 'axes_x_speed',
        'axes_x_inverted': 'axes_x_inverted',
        'axes_y_inverted': 'axes_y_inverted',
        'axes_y_speed': 'axes_y_speed',
        'axes_z_inverted': 'axes_z_inverted',
        'axes_z_speed': 'axes_z_speed',
        'extruder_count': 'extruder_count',
        'extruder_nozzle_diameter': 'extruder_nozzle_diameter',
        'extruder_shared_nozzle': 'extruder_shared_nozzle',
        'heated_bed': 'heated_bed',
        'heated_chamber': 'heated_chamber',
        'model': 'model',
        'name': 'name',
        'octoprint_key': 'octoprint_key',
        'volume_custom_box': 'volume_custom_box',
        'volume_depth': 'volume_depth',
        'volume_formfactor': 'volume_formfactor',
        'volume_height': 'volume_height',
        'volume_origin': 'volume_origin',
        'volume_width': 'volume_width',
        'url': 'url'
    }

    def __init__(self, id=None, user=None, octoprint_device=None, axes_e_inverted=None, axes_e_speed=None, axes_x_speed=None, axes_x_inverted=None, axes_y_inverted=None, axes_y_speed=None, axes_z_inverted=None, axes_z_speed=None, extruder_count=None, extruder_nozzle_diameter=None, extruder_shared_nozzle=None, heated_bed=None, heated_chamber=None, model=None, name=None, octoprint_key=None, volume_custom_box=None, volume_depth=None, volume_formfactor=None, volume_height=None, volume_origin=None, volume_width=None, url=None, local_vars_configuration=None):  # noqa: E501
        """PrinterProfile - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user = None
        self._octoprint_device = None
        self._axes_e_inverted = None
        self._axes_e_speed = None
        self._axes_x_speed = None
        self._axes_x_inverted = None
        self._axes_y_inverted = None
        self._axes_y_speed = None
        self._axes_z_inverted = None
        self._axes_z_speed = None
        self._extruder_count = None
        self._extruder_nozzle_diameter = None
        self._extruder_shared_nozzle = None
        self._heated_bed = None
        self._heated_chamber = None
        self._model = None
        self._name = None
        self._octoprint_key = None
        self._volume_custom_box = None
        self._volume_depth = None
        self._volume_formfactor = None
        self._volume_height = None
        self._volume_origin = None
        self._volume_width = None
        self._url = None
        self.discriminator = None

        self.id = id
        self.user = user
        self.octoprint_device = octoprint_device
        self.axes_e_inverted = axes_e_inverted
        self.axes_e_speed = axes_e_speed
        self.axes_x_speed = axes_x_speed
        self.axes_x_inverted = axes_x_inverted
        self.axes_y_inverted = axes_y_inverted
        self.axes_y_speed = axes_y_speed
        self.axes_z_inverted = axes_z_inverted
        self.axes_z_speed = axes_z_speed
        self.extruder_count = extruder_count
        self.extruder_nozzle_diameter = extruder_nozzle_diameter
        self.extruder_shared_nozzle = extruder_shared_nozzle
        self.heated_bed = heated_bed
        self.heated_chamber = heated_chamber
        self.model = model
        self.name = name
        self.octoprint_key = octoprint_key
        if volume_custom_box is not None:
            self.volume_custom_box = volume_custom_box
        self.volume_depth = volume_depth
        self.volume_formfactor = volume_formfactor
        self.volume_height = volume_height
        self.volume_origin = volume_origin
        self.volume_width = volume_width
        self.url = url

    @property
    def id(self):
        """Gets the id of this PrinterProfile.  # noqa: E501


        :return: The id of this PrinterProfile.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PrinterProfile.


        :param id: The id of this PrinterProfile.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def user(self):
        """Gets the user of this PrinterProfile.  # noqa: E501


        :return: The user of this PrinterProfile.  # noqa: E501
        :rtype: int
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this PrinterProfile.


        :param user: The user of this PrinterProfile.  # noqa: E501
        :type user: int
        """
        if self.local_vars_configuration.client_side_validation and user is None:  # noqa: E501
            raise ValueError("Invalid value for `user`, must not be `None`")  # noqa: E501

        self._user = user

    @property
    def octoprint_device(self):
        """Gets the octoprint_device of this PrinterProfile.  # noqa: E501


        :return: The octoprint_device of this PrinterProfile.  # noqa: E501
        :rtype: int
        """
        return self._octoprint_device

    @octoprint_device.setter
    def octoprint_device(self, octoprint_device):
        """Sets the octoprint_device of this PrinterProfile.


        :param octoprint_device: The octoprint_device of this PrinterProfile.  # noqa: E501
        :type octoprint_device: int
        """
        if self.local_vars_configuration.client_side_validation and octoprint_device is None:  # noqa: E501
            raise ValueError("Invalid value for `octoprint_device`, must not be `None`")  # noqa: E501

        self._octoprint_device = octoprint_device

    @property
    def axes_e_inverted(self):
        """Gets the axes_e_inverted of this PrinterProfile.  # noqa: E501


        :return: The axes_e_inverted of this PrinterProfile.  # noqa: E501
        :rtype: bool
        """
        return self._axes_e_inverted

    @axes_e_inverted.setter
    def axes_e_inverted(self, axes_e_inverted):
        """Sets the axes_e_inverted of this PrinterProfile.


        :param axes_e_inverted: The axes_e_inverted of this PrinterProfile.  # noqa: E501
        :type axes_e_inverted: bool
        """

        self._axes_e_inverted = axes_e_inverted

    @property
    def axes_e_speed(self):
        """Gets the axes_e_speed of this PrinterProfile.  # noqa: E501


        :return: The axes_e_speed of this PrinterProfile.  # noqa: E501
        :rtype: int
        """
        return self._axes_e_speed

    @axes_e_speed.setter
    def axes_e_speed(self, axes_e_speed):
        """Sets the axes_e_speed of this PrinterProfile.


        :param axes_e_speed: The axes_e_speed of this PrinterProfile.  # noqa: E501
        :type axes_e_speed: int
        """
        if (self.local_vars_configuration.client_side_validation and
                axes_e_speed is not None and axes_e_speed > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `axes_e_speed`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                axes_e_speed is not None and axes_e_speed < -2147483648):  # noqa: E501
            raise ValueError("Invalid value for `axes_e_speed`, must be a value greater than or equal to `-2147483648`")  # noqa: E501

        self._axes_e_speed = axes_e_speed

    @property
    def axes_x_speed(self):
        """Gets the axes_x_speed of this PrinterProfile.  # noqa: E501


        :return: The axes_x_speed of this PrinterProfile.  # noqa: E501
        :rtype: int
        """
        return self._axes_x_speed

    @axes_x_speed.setter
    def axes_x_speed(self, axes_x_speed):
        """Sets the axes_x_speed of this PrinterProfile.


        :param axes_x_speed: The axes_x_speed of this PrinterProfile.  # noqa: E501
        :type axes_x_speed: int
        """
        if (self.local_vars_configuration.client_side_validation and
                axes_x_speed is not None and axes_x_speed > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `axes_x_speed`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                axes_x_speed is not None and axes_x_speed < -2147483648):  # noqa: E501
            raise ValueError("Invalid value for `axes_x_speed`, must be a value greater than or equal to `-2147483648`")  # noqa: E501

        self._axes_x_speed = axes_x_speed

    @property
    def axes_x_inverted(self):
        """Gets the axes_x_inverted of this PrinterProfile.  # noqa: E501


        :return: The axes_x_inverted of this PrinterProfile.  # noqa: E501
        :rtype: bool
        """
        return self._axes_x_inverted

    @axes_x_inverted.setter
    def axes_x_inverted(self, axes_x_inverted):
        """Sets the axes_x_inverted of this PrinterProfile.


        :param axes_x_inverted: The axes_x_inverted of this PrinterProfile.  # noqa: E501
        :type axes_x_inverted: bool
        """

        self._axes_x_inverted = axes_x_inverted

    @property
    def axes_y_inverted(self):
        """Gets the axes_y_inverted of this PrinterProfile.  # noqa: E501


        :return: The axes_y_inverted of this PrinterProfile.  # noqa: E501
        :rtype: bool
        """
        return self._axes_y_inverted

    @axes_y_inverted.setter
    def axes_y_inverted(self, axes_y_inverted):
        """Sets the axes_y_inverted of this PrinterProfile.


        :param axes_y_inverted: The axes_y_inverted of this PrinterProfile.  # noqa: E501
        :type axes_y_inverted: bool
        """

        self._axes_y_inverted = axes_y_inverted

    @property
    def axes_y_speed(self):
        """Gets the axes_y_speed of this PrinterProfile.  # noqa: E501


        :return: The axes_y_speed of this PrinterProfile.  # noqa: E501
        :rtype: int
        """
        return self._axes_y_speed

    @axes_y_speed.setter
    def axes_y_speed(self, axes_y_speed):
        """Sets the axes_y_speed of this PrinterProfile.


        :param axes_y_speed: The axes_y_speed of this PrinterProfile.  # noqa: E501
        :type axes_y_speed: int
        """
        if (self.local_vars_configuration.client_side_validation and
                axes_y_speed is not None and axes_y_speed > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `axes_y_speed`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                axes_y_speed is not None and axes_y_speed < -2147483648):  # noqa: E501
            raise ValueError("Invalid value for `axes_y_speed`, must be a value greater than or equal to `-2147483648`")  # noqa: E501

        self._axes_y_speed = axes_y_speed

    @property
    def axes_z_inverted(self):
        """Gets the axes_z_inverted of this PrinterProfile.  # noqa: E501


        :return: The axes_z_inverted of this PrinterProfile.  # noqa: E501
        :rtype: bool
        """
        return self._axes_z_inverted

    @axes_z_inverted.setter
    def axes_z_inverted(self, axes_z_inverted):
        """Sets the axes_z_inverted of this PrinterProfile.


        :param axes_z_inverted: The axes_z_inverted of this PrinterProfile.  # noqa: E501
        :type axes_z_inverted: bool
        """

        self._axes_z_inverted = axes_z_inverted

    @property
    def axes_z_speed(self):
        """Gets the axes_z_speed of this PrinterProfile.  # noqa: E501


        :return: The axes_z_speed of this PrinterProfile.  # noqa: E501
        :rtype: int
        """
        return self._axes_z_speed

    @axes_z_speed.setter
    def axes_z_speed(self, axes_z_speed):
        """Sets the axes_z_speed of this PrinterProfile.


        :param axes_z_speed: The axes_z_speed of this PrinterProfile.  # noqa: E501
        :type axes_z_speed: int
        """
        if (self.local_vars_configuration.client_side_validation and
                axes_z_speed is not None and axes_z_speed > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `axes_z_speed`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                axes_z_speed is not None and axes_z_speed < -2147483648):  # noqa: E501
            raise ValueError("Invalid value for `axes_z_speed`, must be a value greater than or equal to `-2147483648`")  # noqa: E501

        self._axes_z_speed = axes_z_speed

    @property
    def extruder_count(self):
        """Gets the extruder_count of this PrinterProfile.  # noqa: E501


        :return: The extruder_count of this PrinterProfile.  # noqa: E501
        :rtype: int
        """
        return self._extruder_count

    @extruder_count.setter
    def extruder_count(self, extruder_count):
        """Sets the extruder_count of this PrinterProfile.


        :param extruder_count: The extruder_count of this PrinterProfile.  # noqa: E501
        :type extruder_count: int
        """
        if (self.local_vars_configuration.client_side_validation and
                extruder_count is not None and extruder_count > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `extruder_count`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                extruder_count is not None and extruder_count < -2147483648):  # noqa: E501
            raise ValueError("Invalid value for `extruder_count`, must be a value greater than or equal to `-2147483648`")  # noqa: E501

        self._extruder_count = extruder_count

    @property
    def extruder_nozzle_diameter(self):
        """Gets the extruder_nozzle_diameter of this PrinterProfile.  # noqa: E501


        :return: The extruder_nozzle_diameter of this PrinterProfile.  # noqa: E501
        :rtype: float
        """
        return self._extruder_nozzle_diameter

    @extruder_nozzle_diameter.setter
    def extruder_nozzle_diameter(self, extruder_nozzle_diameter):
        """Sets the extruder_nozzle_diameter of this PrinterProfile.


        :param extruder_nozzle_diameter: The extruder_nozzle_diameter of this PrinterProfile.  # noqa: E501
        :type extruder_nozzle_diameter: float
        """

        self._extruder_nozzle_diameter = extruder_nozzle_diameter

    @property
    def extruder_shared_nozzle(self):
        """Gets the extruder_shared_nozzle of this PrinterProfile.  # noqa: E501


        :return: The extruder_shared_nozzle of this PrinterProfile.  # noqa: E501
        :rtype: bool
        """
        return self._extruder_shared_nozzle

    @extruder_shared_nozzle.setter
    def extruder_shared_nozzle(self, extruder_shared_nozzle):
        """Sets the extruder_shared_nozzle of this PrinterProfile.


        :param extruder_shared_nozzle: The extruder_shared_nozzle of this PrinterProfile.  # noqa: E501
        :type extruder_shared_nozzle: bool
        """

        self._extruder_shared_nozzle = extruder_shared_nozzle

    @property
    def heated_bed(self):
        """Gets the heated_bed of this PrinterProfile.  # noqa: E501


        :return: The heated_bed of this PrinterProfile.  # noqa: E501
        :rtype: bool
        """
        return self._heated_bed

    @heated_bed.setter
    def heated_bed(self, heated_bed):
        """Sets the heated_bed of this PrinterProfile.


        :param heated_bed: The heated_bed of this PrinterProfile.  # noqa: E501
        :type heated_bed: bool
        """

        self._heated_bed = heated_bed

    @property
    def heated_chamber(self):
        """Gets the heated_chamber of this PrinterProfile.  # noqa: E501


        :return: The heated_chamber of this PrinterProfile.  # noqa: E501
        :rtype: bool
        """
        return self._heated_chamber

    @heated_chamber.setter
    def heated_chamber(self, heated_chamber):
        """Sets the heated_chamber of this PrinterProfile.


        :param heated_chamber: The heated_chamber of this PrinterProfile.  # noqa: E501
        :type heated_chamber: bool
        """

        self._heated_chamber = heated_chamber

    @property
    def model(self):
        """Gets the model of this PrinterProfile.  # noqa: E501


        :return: The model of this PrinterProfile.  # noqa: E501
        :rtype: str
        """
        return self._model

    @model.setter
    def model(self, model):
        """Sets the model of this PrinterProfile.


        :param model: The model of this PrinterProfile.  # noqa: E501
        :type model: str
        """
        if (self.local_vars_configuration.client_side_validation and
                model is not None and len(model) > 255):
            raise ValueError("Invalid value for `model`, length must be less than or equal to `255`")  # noqa: E501

        self._model = model

    @property
    def name(self):
        """Gets the name of this PrinterProfile.  # noqa: E501


        :return: The name of this PrinterProfile.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PrinterProfile.


        :param name: The name of this PrinterProfile.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 255):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `255`")  # noqa: E501

        self._name = name

    @property
    def octoprint_key(self):
        """Gets the octoprint_key of this PrinterProfile.  # noqa: E501


        :return: The octoprint_key of this PrinterProfile.  # noqa: E501
        :rtype: str
        """
        return self._octoprint_key

    @octoprint_key.setter
    def octoprint_key(self, octoprint_key):
        """Sets the octoprint_key of this PrinterProfile.


        :param octoprint_key: The octoprint_key of this PrinterProfile.  # noqa: E501
        :type octoprint_key: str
        """
        if self.local_vars_configuration.client_side_validation and octoprint_key is None:  # noqa: E501
            raise ValueError("Invalid value for `octoprint_key`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                octoprint_key is not None and len(octoprint_key) > 255):
            raise ValueError("Invalid value for `octoprint_key`, length must be less than or equal to `255`")  # noqa: E501

        self._octoprint_key = octoprint_key

    @property
    def volume_custom_box(self):
        """Gets the volume_custom_box of this PrinterProfile.  # noqa: E501


        :return: The volume_custom_box of this PrinterProfile.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._volume_custom_box

    @volume_custom_box.setter
    def volume_custom_box(self, volume_custom_box):
        """Sets the volume_custom_box of this PrinterProfile.


        :param volume_custom_box: The volume_custom_box of this PrinterProfile.  # noqa: E501
        :type volume_custom_box: dict(str, object)
        """

        self._volume_custom_box = volume_custom_box

    @property
    def volume_depth(self):
        """Gets the volume_depth of this PrinterProfile.  # noqa: E501


        :return: The volume_depth of this PrinterProfile.  # noqa: E501
        :rtype: float
        """
        return self._volume_depth

    @volume_depth.setter
    def volume_depth(self, volume_depth):
        """Sets the volume_depth of this PrinterProfile.


        :param volume_depth: The volume_depth of this PrinterProfile.  # noqa: E501
        :type volume_depth: float
        """

        self._volume_depth = volume_depth

    @property
    def volume_formfactor(self):
        """Gets the volume_formfactor of this PrinterProfile.  # noqa: E501


        :return: The volume_formfactor of this PrinterProfile.  # noqa: E501
        :rtype: str
        """
        return self._volume_formfactor

    @volume_formfactor.setter
    def volume_formfactor(self, volume_formfactor):
        """Sets the volume_formfactor of this PrinterProfile.


        :param volume_formfactor: The volume_formfactor of this PrinterProfile.  # noqa: E501
        :type volume_formfactor: str
        """
        if (self.local_vars_configuration.client_side_validation and
                volume_formfactor is not None and len(volume_formfactor) > 255):
            raise ValueError("Invalid value for `volume_formfactor`, length must be less than or equal to `255`")  # noqa: E501

        self._volume_formfactor = volume_formfactor

    @property
    def volume_height(self):
        """Gets the volume_height of this PrinterProfile.  # noqa: E501


        :return: The volume_height of this PrinterProfile.  # noqa: E501
        :rtype: float
        """
        return self._volume_height

    @volume_height.setter
    def volume_height(self, volume_height):
        """Sets the volume_height of this PrinterProfile.


        :param volume_height: The volume_height of this PrinterProfile.  # noqa: E501
        :type volume_height: float
        """

        self._volume_height = volume_height

    @property
    def volume_origin(self):
        """Gets the volume_origin of this PrinterProfile.  # noqa: E501


        :return: The volume_origin of this PrinterProfile.  # noqa: E501
        :rtype: str
        """
        return self._volume_origin

    @volume_origin.setter
    def volume_origin(self, volume_origin):
        """Sets the volume_origin of this PrinterProfile.


        :param volume_origin: The volume_origin of this PrinterProfile.  # noqa: E501
        :type volume_origin: str
        """
        if (self.local_vars_configuration.client_side_validation and
                volume_origin is not None and len(volume_origin) > 255):
            raise ValueError("Invalid value for `volume_origin`, length must be less than or equal to `255`")  # noqa: E501

        self._volume_origin = volume_origin

    @property
    def volume_width(self):
        """Gets the volume_width of this PrinterProfile.  # noqa: E501


        :return: The volume_width of this PrinterProfile.  # noqa: E501
        :rtype: float
        """
        return self._volume_width

    @volume_width.setter
    def volume_width(self, volume_width):
        """Sets the volume_width of this PrinterProfile.


        :param volume_width: The volume_width of this PrinterProfile.  # noqa: E501
        :type volume_width: float
        """

        self._volume_width = volume_width

    @property
    def url(self):
        """Gets the url of this PrinterProfile.  # noqa: E501


        :return: The url of this PrinterProfile.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this PrinterProfile.


        :param url: The url of this PrinterProfile.  # noqa: E501
        :type url: str
        """
        if self.local_vars_configuration.client_side_validation and url is None:  # noqa: E501
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PrinterProfile):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PrinterProfile):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class Alert(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'time': 'str',
        'gcode_file': 'str',
        'print_progress': 'str',
        'time_elapsed': 'str',
        'time_remaining': 'str',
        'manage_device_url': 'str',
        'user': 'int',
        'octoprint_device': 'int',
        'event_type': 'AlertEventTypeEnum',
        'seen': 'bool',
        'sent': 'bool',
        'created_dt': 'datetime',
        'updated_dt': 'datetime',
        'message': 'str'
    }

    attribute_map = {
        'id': 'id',
        'time': 'time',
        'gcode_file': 'gcode_file',
        'print_progress': 'print_progress',
        'time_elapsed': 'time_elapsed',
        'time_remaining': 'time_remaining',
        'manage_device_url': 'manage_device_url',
        'user': 'user',
        'octoprint_device': 'octoprint_device',
        'event_type': 'event_type',
        'seen': 'seen',
        'sent': 'sent',
        'created_dt': 'created_dt',
        'updated_dt': 'updated_dt',
        'message': 'message'
    }

    def __init__(self, id=None, time=None, gcode_file=None, print_progress=None, time_elapsed=None, time_remaining=None, manage_device_url=None, user=None, octoprint_device=None, event_type=None, seen=None, sent=None, created_dt=None, updated_dt=None, message=None, local_vars_configuration=None):  # noqa: E501
        """Alert - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._time = None
        self._gcode_file = None
        self._print_progress = None
        self._time_elapsed = None
        self._time_remaining = None
        self._manage_device_url = None
        self._user = None
        self._octoprint_device = None
        self._event_type = None
        self._seen = None
        self._sent = None
        self._created_dt = None
        self._updated_dt = None
        self._message = None
        self.discriminator = None

        self.id = id
        self.time = time
        self.gcode_file = gcode_file
        self.print_progress = print_progress
        self.time_elapsed = time_elapsed
        self.time_remaining = time_remaining
        self.manage_device_url = manage_device_url
        self.user = user
        self.octoprint_device = octoprint_device
        self.event_type = event_type
        if seen is not None:
            self.seen = seen
        if sent is not None:
            self.sent = sent
        self.created_dt = created_dt
        self.updated_dt = updated_dt
        self.message = message

    @property
    def id(self):
        """Gets the id of this Alert.  # noqa: E501


        :return: The id of this Alert.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Alert.


        :param id: The id of this Alert.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def time(self):
        """Gets the time of this Alert.  # noqa: E501


        :return: The time of this Alert.  # noqa: E501
        :rtype: str
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this Alert.


        :param time: The time of this Alert.  # noqa: E501
        :type time: str
        """
        if self.local_vars_configuration.client_side_validation and time is None:  # noqa: E501
            raise ValueError("Invalid value for `time`, must not be `None`")  # noqa: E501

        self._time = time

    @property
    def gcode_file(self):
        """Gets the gcode_file of this Alert.  # noqa: E501


        :return: The gcode_file of this Alert.  # noqa: E501
        :rtype: str
        """
        return self._gcode_file

    @gcode_file.setter
    def gcode_file(self, gcode_file):
        """Sets the gcode_file of this Alert.


        :param gcode_file: The gcode_file of this Alert.  # noqa: E501
        :type gcode_file: str
        """
        if self.local_vars_configuration.client_side_validation and gcode_file is None:  # noqa: E501
            raise ValueError("Invalid value for `gcode_file`, must not be `None`")  # noqa: E501

        self._gcode_file = gcode_file

    @property
    def print_progress(self):
        """Gets the print_progress of this Alert.  # noqa: E501


        :return: The print_progress of this Alert.  # noqa: E501
        :rtype: str
        """
        return self._print_progress

    @print_progress.setter
    def print_progress(self, print_progress):
        """Sets the print_progress of this Alert.


        :param print_progress: The print_progress of this Alert.  # noqa: E501
        :type print_progress: str
        """
        if self.local_vars_configuration.client_side_validation and print_progress is None:  # noqa: E501
            raise ValueError("Invalid value for `print_progress`, must not be `None`")  # noqa: E501

        self._print_progress = print_progress

    @property
    def time_elapsed(self):
        """Gets the time_elapsed of this Alert.  # noqa: E501


        :return: The time_elapsed of this Alert.  # noqa: E501
        :rtype: str
        """
        return self._time_elapsed

    @time_elapsed.setter
    def time_elapsed(self, time_elapsed):
        """Sets the time_elapsed of this Alert.


        :param time_elapsed: The time_elapsed of this Alert.  # noqa: E501
        :type time_elapsed: str
        """
        if self.local_vars_configuration.client_side_validation and time_elapsed is None:  # noqa: E501
            raise ValueError("Invalid value for `time_elapsed`, must not be `None`")  # noqa: E501

        self._time_elapsed = time_elapsed

    @property
    def time_remaining(self):
        """Gets the time_remaining of this Alert.  # noqa: E501


        :return: The time_remaining of this Alert.  # noqa: E501
        :rtype: str
        """
        return self._time_remaining

    @time_remaining.setter
    def time_remaining(self, time_remaining):
        """Sets the time_remaining of this Alert.


        :param time_remaining: The time_remaining of this Alert.  # noqa: E501
        :type time_remaining: str
        """
        if self.local_vars_configuration.client_side_validation and time_remaining is None:  # noqa: E501
            raise ValueError("Invalid value for `time_remaining`, must not be `None`")  # noqa: E501

        self._time_remaining = time_remaining

    @property
    def manage_device_url(self):
        """Gets the manage_device_url of this Alert.  # noqa: E501


        :return: The manage_device_url of this Alert.  # noqa: E501
        :rtype: str
        """
        return self._manage_device_url

    @manage_device_url.setter
    def manage_device_url(self, manage_device_url):
        """Sets the manage_device_url of this Alert.


        :param manage_device_url: The manage_device_url of this Alert.  # noqa: E501
        :type manage_device_url: str
        """

        self._manage_device_url = manage_device_url

    @property
    def user(self):
        """Gets the user of this Alert.  # noqa: E501


        :return: The user of this Alert.  # noqa: E501
        :rtype: int
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this Alert.


        :param user: The user of this Alert.  # noqa: E501
        :type user: int
        """
        if self.local_vars_configuration.client_side_validation and user is None:  # noqa: E501
            raise ValueError("Invalid value for `user`, must not be `None`")  # noqa: E501

        self._user = user

    @property
    def octoprint_device(self):
        """Gets the octoprint_device of this Alert.  # noqa: E501


        :return: The octoprint_device of this Alert.  # noqa: E501
        :rtype: int
        """
        return self._octoprint_device

    @octoprint_device.setter
    def octoprint_device(self, octoprint_device):
        """Sets the octoprint_device of this Alert.


        :param octoprint_device: The octoprint_device of this Alert.  # noqa: E501
        :type octoprint_device: int
        """

        self._octoprint_device = octoprint_device

    @property
    def event_type(self):
        """Gets the event_type of this Alert.  # noqa: E501


        :return: The event_type of this Alert.  # noqa: E501
        :rtype: AlertEventTypeEnum
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this Alert.


        :param event_type: The event_type of this Alert.  # noqa: E501
        :type event_type: AlertEventTypeEnum
        """

        self._event_type = event_type

    @property
    def seen(self):
        """Gets the seen of this Alert.  # noqa: E501


        :return: The seen of this Alert.  # noqa: E501
        :rtype: bool
        """
        return self._seen

    @seen.setter
    def seen(self, seen):
        """Sets the seen of this Alert.


        :param seen: The seen of this Alert.  # noqa: E501
        :type seen: bool
        """

        self._seen = seen

    @property
    def sent(self):
        """Gets the sent of this Alert.  # noqa: E501


        :return: The sent of this Alert.  # noqa: E501
        :rtype: bool
        """
        return self._sent

    @sent.setter
    def sent(self, sent):
        """Sets the sent of this Alert.


        :param sent: The sent of this Alert.  # noqa: E501
        :type sent: bool
        """

        self._sent = sent

    @property
    def created_dt(self):
        """Gets the created_dt of this Alert.  # noqa: E501


        :return: The created_dt of this Alert.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this Alert.


        :param created_dt: The created_dt of this Alert.  # noqa: E501
        :type created_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `created_dt`, must not be `None`")  # noqa: E501

        self._created_dt = created_dt

    @property
    def updated_dt(self):
        """Gets the updated_dt of this Alert.  # noqa: E501


        :return: The updated_dt of this Alert.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this Alert.


        :param updated_dt: The updated_dt of this Alert.  # noqa: E501
        :type updated_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_dt`, must not be `None`")  # noqa: E501

        self._updated_dt = updated_dt

    @property
    def message(self):
        """Gets the message of this Alert.  # noqa: E501


        :return: The message of this Alert.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this Alert.


        :param message: The message of this Alert.  # noqa: E501
        :type message: str
        """
        if self.local_vars_configuration.client_side_validation and message is None:  # noqa: E501
            raise ValueError("Invalid value for `message`, must not be `None`")  # noqa: E501

        self._message = message

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Alert):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Alert):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class Partner3DGeeksMetadata(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'model': 'str',
        'platform': 'str',
        'octoprint_version': 'str',
        'print_nanny_plugin_version': 'str',
        'print_nanny_client_version': 'str',
        'verified': 'str'
    }

    attribute_map = {
        'name': 'name',
        'model': 'model',
        'platform': 'platform',
        'octoprint_version': 'octoprint_version',
        'print_nanny_plugin_version': 'print_nanny_plugin_version',
        'print_nanny_client_version': 'print_nanny_client_version',
        'verified': 'verified'
    }

    def __init__(self, name=None, model=None, platform=None, octoprint_version=None, print_nanny_plugin_version=None, print_nanny_client_version=None, verified=None, local_vars_configuration=None):  # noqa: E501
        """Partner3DGeeksMetadata - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._model = None
        self._platform = None
        self._octoprint_version = None
        self._print_nanny_plugin_version = None
        self._print_nanny_client_version = None
        self._verified = None
        self.discriminator = None

        self.name = name
        self.model = model
        self.platform = platform
        self.octoprint_version = octoprint_version
        self.print_nanny_plugin_version = print_nanny_plugin_version
        self.print_nanny_client_version = print_nanny_client_version
        self.verified = verified

    @property
    def name(self):
        """Gets the name of this Partner3DGeeksMetadata.  # noqa: E501


        :return: The name of this Partner3DGeeksMetadata.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Partner3DGeeksMetadata.


        :param name: The name of this Partner3DGeeksMetadata.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 255):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `255`")  # noqa: E501

        self._name = name

    @property
    def model(self):
        """Gets the model of this Partner3DGeeksMetadata.  # noqa: E501


        :return: The model of this Partner3DGeeksMetadata.  # noqa: E501
        :rtype: str
        """
        return self._model

    @model.setter
    def model(self, model):
        """Sets the model of this Partner3DGeeksMetadata.


        :param model: The model of this Partner3DGeeksMetadata.  # noqa: E501
        :type model: str
        """
        if self.local_vars_configuration.client_side_validation and model is None:  # noqa: E501
            raise ValueError("Invalid value for `model`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                model is not None and len(model) > 255):
            raise ValueError("Invalid value for `model`, length must be less than or equal to `255`")  # noqa: E501

        self._model = model

    @property
    def platform(self):
        """Gets the platform of this Partner3DGeeksMetadata.  # noqa: E501


        :return: The platform of this Partner3DGeeksMetadata.  # noqa: E501
        :rtype: str
        """
        return self._platform

    @platform.setter
    def platform(self, platform):
        """Sets the platform of this Partner3DGeeksMetadata.


        :param platform: The platform of this Partner3DGeeksMetadata.  # noqa: E501
        :type platform: str
        """
        if self.local_vars_configuration.client_side_validation and platform is None:  # noqa: E501
            raise ValueError("Invalid value for `platform`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                platform is not None and len(platform) > 255):
            raise ValueError("Invalid value for `platform`, length must be less than or equal to `255`")  # noqa: E501

        self._platform = platform

    @property
    def octoprint_version(self):
        """Gets the octoprint_version of this Partner3DGeeksMetadata.  # noqa: E501


        :return: The octoprint_version of this Partner3DGeeksMetadata.  # noqa: E501
        :rtype: str
        """
        return self._octoprint_version

    @octoprint_version.setter
    def octoprint_version(self, octoprint_version):
        """Sets the octoprint_version of this Partner3DGeeksMetadata.


        :param octoprint_version: The octoprint_version of this Partner3DGeeksMetadata.  # noqa: E501
        :type octoprint_version: str
        """
        if self.local_vars_configuration.client_side_validation and octoprint_version is None:  # noqa: E501
            raise ValueError("Invalid value for `octoprint_version`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                octoprint_version is not None and len(octoprint_version) > 255):
            raise ValueError("Invalid value for `octoprint_version`, length must be less than or equal to `255`")  # noqa: E501

        self._octoprint_version = octoprint_version

    @property
    def print_nanny_plugin_version(self):
        """Gets the print_nanny_plugin_version of this Partner3DGeeksMetadata.  # noqa: E501


        :return: The print_nanny_plugin_version of this Partner3DGeeksMetadata.  # noqa: E501
        :rtype: str
        """
        return self._print_nanny_plugin_version

    @print_nanny_plugin_version.setter
    def print_nanny_plugin_version(self, print_nanny_plugin_version):
        """Sets the print_nanny_plugin_version of this Partner3DGeeksMetadata.


        :param print_nanny_plugin_version: The print_nanny_plugin_version of this Partner3DGeeksMetadata.  # noqa: E501
        :type print_nanny_plugin_version: str
        """
        if self.local_vars_configuration.client_side_validation and print_nanny_plugin_version is None:  # noqa: E501
            raise ValueError("Invalid value for `print_nanny_plugin_version`, must not be `None`")  # noqa: E501

        self._print_nanny_plugin_version = print_nanny_plugin_version

    @property
    def print_nanny_client_version(self):
        """Gets the print_nanny_client_version of this Partner3DGeeksMetadata.  # noqa: E501


        :return: The print_nanny_client_version of this Partner3DGeeksMetadata.  # noqa: E501
        :rtype: str
        """
        return self._print_nanny_client_version

    @print_nanny_client_version.setter
    def print_nanny_client_version(self, print_nanny_client_version):
        """Sets the print_nanny_client_version of this Partner3DGeeksMetadata.


        :param print_nanny_client_version: The print_nanny_client_version of this Partner3DGeeksMetadata.  # noqa: E501
        :type print_nanny_client_version: str
        """
        if self.local_vars_configuration.client_side_validation and print_nanny_client_version is None:  # noqa: E501
            raise ValueError("Invalid value for `print_nanny_client_version`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                print_nanny_client_version is not None and len(print_nanny_client_version) > 255):
            raise ValueError("Invalid value for `print_nanny_client_version`, length must be less than or equal to `255`")  # noqa: E501

        self._print_nanny_client_version = print_nanny_client_version

    @property
    def verified(self):
        """Gets the verified of this Partner3DGeeksMetadata.  # noqa: E501


        :return: The verified of this Partner3DGeeksMetadata.  # noqa: E501
        :rtype: str
        """
        return self._verified

    @verified.setter
    def verified(self, verified):
        """Sets the verified of this Partner3DGeeksMetadata.


        :param verified: The verified of this Partner3DGeeksMetadata.  # noqa: E501
        :type verified: str
        """
        if self.local_vars_configuration.client_side_validation and verified is None:  # noqa: E501
            raise ValueError("Invalid value for `verified`, must not be `None`")  # noqa: E501

        self._verified = verified

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Partner3DGeeksMetadata):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Partner3DGeeksMetadata):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class RemoteControlCommandRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'command': 'CommandEnum',
        'user': 'int',
        'device': 'int',
        'received': 'bool',
        'success': 'bool',
        'iotcore_response': 'dict(str, object)',
        'metadata': 'dict(str, object)'
    }

    attribute_map = {
        'command': 'command',
        'user': 'user',
        'device': 'device',
        'received': 'received',
        'success': 'success',
        'iotcore_response': 'iotcore_response',
        'metadata': 'metadata'
    }

    def __init__(self, command=None, user=None, device=None, received=None, success=None, iotcore_response=None, metadata=None, local_vars_configuration=None):  # noqa: E501
        """RemoteControlCommandRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._command = None
        self._user = None
        self._device = None
        self._received = None
        self._success = None
        self._iotcore_response = None
        self._metadata = None
        self.discriminator = None

        if command is not None:
            self.command = command
        self.user = user
        self.device = device
        if received is not None:
            self.received = received
        self.success = success
        if iotcore_response is not None:
            self.iotcore_response = iotcore_response
        if metadata is not None:
            self.metadata = metadata

    @property
    def command(self):
        """Gets the command of this RemoteControlCommandRequest.  # noqa: E501


        :return: The command of this RemoteControlCommandRequest.  # noqa: E501
        :rtype: CommandEnum
        """
        return self._command

    @command.setter
    def command(self, command):
        """Sets the command of this RemoteControlCommandRequest.


        :param command: The command of this RemoteControlCommandRequest.  # noqa: E501
        :type command: CommandEnum
        """

        self._command = command

    @property
    def user(self):
        """Gets the user of this RemoteControlCommandRequest.  # noqa: E501


        :return: The user of this RemoteControlCommandRequest.  # noqa: E501
        :rtype: int
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this RemoteControlCommandRequest.


        :param user: The user of this RemoteControlCommandRequest.  # noqa: E501
        :type user: int
        """
        if self.local_vars_configuration.client_side_validation and user is None:  # noqa: E501
            raise ValueError("Invalid value for `user`, must not be `None`")  # noqa: E501

        self._user = user

    @property
    def device(self):
        """Gets the device of this RemoteControlCommandRequest.  # noqa: E501


        :return: The device of this RemoteControlCommandRequest.  # noqa: E501
        :rtype: int
        """
        return self._device

    @device.setter
    def device(self, device):
        """Sets the device of this RemoteControlCommandRequest.


        :param device: The device of this RemoteControlCommandRequest.  # noqa: E501
        :type device: int
        """
        if self.local_vars_configuration.client_side_validation and device is None:  # noqa: E501
            raise ValueError("Invalid value for `device`, must not be `None`")  # noqa: E501

        self._device = device

    @property
    def received(self):
        """Gets the received of this RemoteControlCommandRequest.  # noqa: E501


        :return: The received of this RemoteControlCommandRequest.  # noqa: E501
        :rtype: bool
        """
        return self._received

    @received.setter
    def received(self, received):
        """Sets the received of this RemoteControlCommandRequest.


        :param received: The received of this RemoteControlCommandRequest.  # noqa: E501
        :type received: bool
        """

        self._received = received

    @property
    def success(self):
        """Gets the success of this RemoteControlCommandRequest.  # noqa: E501


        :return: The success of this RemoteControlCommandRequest.  # noqa: E501
        :rtype: bool
        """
        return self._success

    @success.setter
    def success(self, success):
        """Sets the success of this RemoteControlCommandRequest.


        :param success: The success of this RemoteControlCommandRequest.  # noqa: E501
        :type success: bool
        """

        self._success = success

    @property
    def iotcore_response(self):
        """Gets the iotcore_response of this RemoteControlCommandRequest.  # noqa: E501


        :return: The iotcore_response of this RemoteControlCommandRequest.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._iotcore_response

    @iotcore_response.setter
    def iotcore_response(self, iotcore_response):
        """Sets the iotcore_response of this RemoteControlCommandRequest.


        :param iotcore_response: The iotcore_response of this RemoteControlCommandRequest.  # noqa: E501
        :type iotcore_response: dict(str, object)
        """

        self._iotcore_response = iotcore_response

    @property
    def metadata(self):
        """Gets the metadata of this RemoteControlCommandRequest.  # noqa: E501


        :return: The metadata of this RemoteControlCommandRequest.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this RemoteControlCommandRequest.


        :param metadata: The metadata of this RemoteControlCommandRequest.  # noqa: E501
        :type metadata: dict(str, object)
        """

        self._metadata = metadata

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RemoteControlCommandRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RemoteControlCommandRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class OctoprintPrinterFlagsRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'operational': 'bool',
        'printing': 'bool',
        'cancelling': 'bool',
        'pausing': 'bool',
        'resuming': 'bool',
        'finishing': 'bool',
        'closed_or_error': 'bool',
        'error': 'bool',
        'paused': 'bool',
        'ready': 'bool',
        'sd_ready': 'bool'
    }

    attribute_map = {
        'operational': 'operational',
        'printing': 'printing',
        'cancelling': 'cancelling',
        'pausing': 'pausing',
        'resuming': 'resuming',
        'finishing': 'finishing',
        'closed_or_error': 'closedOrError',
        'error': 'error',
        'paused': 'paused',
        'ready': 'ready',
        'sd_ready': 'sdReady'
    }

    def __init__(self, operational=None, printing=None, cancelling=None, pausing=None, resuming=None, finishing=None, closed_or_error=None, error=None, paused=None, ready=None, sd_ready=None, local_vars_configuration=None):  # noqa: E501
        """OctoprintPrinterFlagsRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._operational = None
        self._printing = None
        self._cancelling = None
        self._pausing = None
        self._resuming = None
        self._finishing = None
        self._closed_or_error = None
        self._error = None
        self._paused = None
        self._ready = None
        self._sd_ready = None
        self.discriminator = None

        self.operational = operational
        self.printing = printing
        self.cancelling = cancelling
        self.pausing = pausing
        self.resuming = resuming
        self.finishing = finishing
        self.closed_or_error = closed_or_error
        self.error = error
        self.paused = paused
        self.ready = ready
        self.sd_ready = sd_ready

    @property
    def operational(self):
        """Gets the operational of this OctoprintPrinterFlagsRequest.  # noqa: E501


        :return: The operational of this OctoprintPrinterFlagsRequest.  # noqa: E501
        :rtype: bool
        """
        return self._operational

    @operational.setter
    def operational(self, operational):
        """Sets the operational of this OctoprintPrinterFlagsRequest.


        :param operational: The operational of this OctoprintPrinterFlagsRequest.  # noqa: E501
        :type operational: bool
        """
        if self.local_vars_configuration.client_side_validation and operational is None:  # noqa: E501
            raise ValueError("Invalid value for `operational`, must not be `None`")  # noqa: E501

        self._operational = operational

    @property
    def printing(self):
        """Gets the printing of this OctoprintPrinterFlagsRequest.  # noqa: E501


        :return: The printing of this OctoprintPrinterFlagsRequest.  # noqa: E501
        :rtype: bool
        """
        return self._printing

    @printing.setter
    def printing(self, printing):
        """Sets the printing of this OctoprintPrinterFlagsRequest.


        :param printing: The printing of this OctoprintPrinterFlagsRequest.  # noqa: E501
        :type printing: bool
        """
        if self.local_vars_configuration.client_side_validation and printing is None:  # noqa: E501
            raise ValueError("Invalid value for `printing`, must not be `None`")  # noqa: E501

        self._printing = printing

    @property
    def cancelling(self):
        """Gets the cancelling of this OctoprintPrinterFlagsRequest.  # noqa: E501


        :return: The cancelling of this OctoprintPrinterFlagsRequest.  # noqa: E501
        :rtype: bool
        """
        return self._cancelling

    @cancelling.setter
    def cancelling(self, cancelling):
        """Sets the cancelling of this OctoprintPrinterFlagsRequest.


        :param cancelling: The cancelling of this OctoprintPrinterFlagsRequest.  # noqa: E501
        :type cancelling: bool
        """
        if self.local_vars_configuration.client_side_validation and cancelling is None:  # noqa: E501
            raise ValueError("Invalid value for `cancelling`, must not be `None`")  # noqa: E501

        self._cancelling = cancelling

    @property
    def pausing(self):
        """Gets the pausing of this OctoprintPrinterFlagsRequest.  # noqa: E501


        :return: The pausing of this OctoprintPrinterFlagsRequest.  # noqa: E501
        :rtype: bool
        """
        return self._pausing

    @pausing.setter
    def pausing(self, pausing):
        """Sets the pausing of this OctoprintPrinterFlagsRequest.


        :param pausing: The pausing of this OctoprintPrinterFlagsRequest.  # noqa: E501
        :type pausing: bool
        """
        if self.local_vars_configuration.client_side_validation and pausing is None:  # noqa: E501
            raise ValueError("Invalid value for `pausing`, must not be `None`")  # noqa: E501

        self._pausing = pausing

    @property
    def resuming(self):
        """Gets the resuming of this OctoprintPrinterFlagsRequest.  # noqa: E501


        :return: The resuming of this OctoprintPrinterFlagsRequest.  # noqa: E501
        :rtype: bool
        """
        return self._resuming

    @resuming.setter
    def resuming(self, resuming):
        """Sets the resuming of this OctoprintPrinterFlagsRequest.


        :param resuming: The resuming of this OctoprintPrinterFlagsRequest.  # noqa: E501
        :type resuming: bool
        """
        if self.local_vars_configuration.client_side_validation and resuming is None:  # noqa: E501
            raise ValueError("Invalid value for `resuming`, must not be `None`")  # noqa: E501

        self._resuming = resuming

    @property
    def finishing(self):
        """Gets the finishing of this OctoprintPrinterFlagsRequest.  # noqa: E501


        :return: The finishing of this OctoprintPrinterFlagsRequest.  # noqa: E501
        :rtype: bool
        """
        return self._finishing

    @finishing.setter
    def finishing(self, finishing):
        """Sets the finishing of this OctoprintPrinterFlagsRequest.


        :param finishing: The finishing of this OctoprintPrinterFlagsRequest.  # noqa: E501
        :type finishing: bool
        """
        if self.local_vars_configuration.client_side_validation and finishing is None:  # noqa: E501
            raise ValueError("Invalid value for `finishing`, must not be `None`")  # noqa: E501

        self._finishing = finishing

    @property
    def closed_or_error(self):
        """Gets the closed_or_error of this OctoprintPrinterFlagsRequest.  # noqa: E501


        :return: The closed_or_error of this OctoprintPrinterFlagsRequest.  # noqa: E501
        :rtype: bool
        """
        return self._closed_or_error

    @closed_or_error.setter
    def closed_or_error(self, closed_or_error):
        """Sets the closed_or_error of this OctoprintPrinterFlagsRequest.


        :param closed_or_error: The closed_or_error of this OctoprintPrinterFlagsRequest.  # noqa: E501
        :type closed_or_error: bool
        """
        if self.local_vars_configuration.client_side_validation and closed_or_error is None:  # noqa: E501
            raise ValueError("Invalid value for `closed_or_error`, must not be `None`")  # noqa: E501

        self._closed_or_error = closed_or_error

    @property
    def error(self):
        """Gets the error of this OctoprintPrinterFlagsRequest.  # noqa: E501


        :return: The error of this OctoprintPrinterFlagsRequest.  # noqa: E501
        :rtype: bool
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this OctoprintPrinterFlagsRequest.


        :param error: The error of this OctoprintPrinterFlagsRequest.  # noqa: E501
        :type error: bool
        """
        if self.local_vars_configuration.client_side_validation and error is None:  # noqa: E501
            raise ValueError("Invalid value for `error`, must not be `None`")  # noqa: E501

        self._error = error

    @property
    def paused(self):
        """Gets the paused of this OctoprintPrinterFlagsRequest.  # noqa: E501


        :return: The paused of this OctoprintPrinterFlagsRequest.  # noqa: E501
        :rtype: bool
        """
        return self._paused

    @paused.setter
    def paused(self, paused):
        """Sets the paused of this OctoprintPrinterFlagsRequest.


        :param paused: The paused of this OctoprintPrinterFlagsRequest.  # noqa: E501
        :type paused: bool
        """
        if self.local_vars_configuration.client_side_validation and paused is None:  # noqa: E501
            raise ValueError("Invalid value for `paused`, must not be `None`")  # noqa: E501

        self._paused = paused

    @property
    def ready(self):
        """Gets the ready of this OctoprintPrinterFlagsRequest.  # noqa: E501


        :return: The ready of this OctoprintPrinterFlagsRequest.  # noqa: E501
        :rtype: bool
        """
        return self._ready

    @ready.setter
    def ready(self, ready):
        """Sets the ready of this OctoprintPrinterFlagsRequest.


        :param ready: The ready of this OctoprintPrinterFlagsRequest.  # noqa: E501
        :type ready: bool
        """
        if self.local_vars_configuration.client_side_validation and ready is None:  # noqa: E501
            raise ValueError("Invalid value for `ready`, must not be `None`")  # noqa: E501

        self._ready = ready

    @property
    def sd_ready(self):
        """Gets the sd_ready of this OctoprintPrinterFlagsRequest.  # noqa: E501


        :return: The sd_ready of this OctoprintPrinterFlagsRequest.  # noqa: E501
        :rtype: bool
        """
        return self._sd_ready

    @sd_ready.setter
    def sd_ready(self, sd_ready):
        """Sets the sd_ready of this OctoprintPrinterFlagsRequest.


        :param sd_ready: The sd_ready of this OctoprintPrinterFlagsRequest.  # noqa: E501
        :type sd_ready: bool
        """
        if self.local_vars_configuration.client_side_validation and sd_ready is None:  # noqa: E501
            raise ValueError("Invalid value for `sd_ready`, must not be `None`")  # noqa: E501

        self._sd_ready = sd_ready

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OctoprintPrinterFlagsRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OctoprintPrinterFlagsRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class OctoprintEnvironment(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'os': 'OctoprintPlatform',
        'python': 'OctoprintPython',
        'hardware': 'OctoprintHardware',
        'pi_support': 'OctoprintPiSupport'
    }

    attribute_map = {
        'os': 'os',
        'python': 'python',
        'hardware': 'hardware',
        'pi_support': 'pi_support'
    }

    def __init__(self, os=None, python=None, hardware=None, pi_support=None, local_vars_configuration=None):  # noqa: E501
        """OctoprintEnvironment - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._os = None
        self._python = None
        self._hardware = None
        self._pi_support = None
        self.discriminator = None

        self.os = os
        self.python = python
        self.hardware = hardware
        self.pi_support = pi_support

    @property
    def os(self):
        """Gets the os of this OctoprintEnvironment.  # noqa: E501


        :return: The os of this OctoprintEnvironment.  # noqa: E501
        :rtype: OctoprintPlatform
        """
        return self._os

    @os.setter
    def os(self, os):
        """Sets the os of this OctoprintEnvironment.


        :param os: The os of this OctoprintEnvironment.  # noqa: E501
        :type os: OctoprintPlatform
        """
        if self.local_vars_configuration.client_side_validation and os is None:  # noqa: E501
            raise ValueError("Invalid value for `os`, must not be `None`")  # noqa: E501

        self._os = os

    @property
    def python(self):
        """Gets the python of this OctoprintEnvironment.  # noqa: E501


        :return: The python of this OctoprintEnvironment.  # noqa: E501
        :rtype: OctoprintPython
        """
        return self._python

    @python.setter
    def python(self, python):
        """Sets the python of this OctoprintEnvironment.


        :param python: The python of this OctoprintEnvironment.  # noqa: E501
        :type python: OctoprintPython
        """
        if self.local_vars_configuration.client_side_validation and python is None:  # noqa: E501
            raise ValueError("Invalid value for `python`, must not be `None`")  # noqa: E501

        self._python = python

    @property
    def hardware(self):
        """Gets the hardware of this OctoprintEnvironment.  # noqa: E501


        :return: The hardware of this OctoprintEnvironment.  # noqa: E501
        :rtype: OctoprintHardware
        """
        return self._hardware

    @hardware.setter
    def hardware(self, hardware):
        """Sets the hardware of this OctoprintEnvironment.


        :param hardware: The hardware of this OctoprintEnvironment.  # noqa: E501
        :type hardware: OctoprintHardware
        """
        if self.local_vars_configuration.client_side_validation and hardware is None:  # noqa: E501
            raise ValueError("Invalid value for `hardware`, must not be `None`")  # noqa: E501

        self._hardware = hardware

    @property
    def pi_support(self):
        """Gets the pi_support of this OctoprintEnvironment.  # noqa: E501


        :return: The pi_support of this OctoprintEnvironment.  # noqa: E501
        :rtype: OctoprintPiSupport
        """
        return self._pi_support

    @pi_support.setter
    def pi_support(self, pi_support):
        """Sets the pi_support of this OctoprintEnvironment.


        :param pi_support: The pi_support of this OctoprintEnvironment.  # noqa: E501
        :type pi_support: OctoprintPiSupport
        """
        if self.local_vars_configuration.client_side_validation and pi_support is None:  # noqa: E501
            raise ValueError("Invalid value for `pi_support`, must not be `None`")  # noqa: E501

        self._pi_support = pi_support

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OctoprintEnvironment):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OctoprintEnvironment):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from printnanny_api_client.api.alerts_api import AlertsApi
from printnanny_api_client.api.auth_api import AuthApi
from printnanny_api_client.api.auth__api import AuthApi
from printnanny_api_client.api.client_config_api import ClientConfigApi
from printnanny_api_client.api.devices_api import DevicesApi
from printnanny_api_client.api.licenses_api import LicensesApi
from printnanny_api_client.api.ml_ops_api import MlOpsApi
from printnanny_api_client.api.partners_geeks3_api import PartnersGeeks3Api
from printnanny_api_client.api.partners_geeks3d_api import PartnersGeeks3dApi
from printnanny_api_client.api.remote_control_api import RemoteControlApi
from printnanny_api_client.api.schema_api import SchemaApi
from printnanny_api_client.api.telemetry_api import TelemetryApi
from printnanny_api_client.api.users_api import UsersApi
